@@ -37,14 +37,14 @@ NormalKernel <- R6Class("NormalKernel",
     #' where X is the Distribution, \eqn{f_X} is its pdf and \eqn{a, b}
     #' are the distribution support limits.
     pdfSquared2Norm = function(x = 0, upper = Inf) {
-      xl = length(x)
-      ul = length(upper)
-      len = max(xl, ul)
+      xl <- length(x)
+      ul <- length(upper)
+      len <- max(xl, ul)
 
       ret <- numeric(len)
       for (i in seq(len)) {
-        xi = x[ifelse(i %% xl == 0, xl, i %% xl)]
-        ui = upper[ifelse(i %% ul == 0, ul, i %% ul)]
+        xi <- x[ifelse(i %% xl == 0, xl, i %% xl)]
+        ui <- upper[ifelse(i %% ul == 0, ul, i %% ul)]
         if (ui == Inf) {
           ret[i] <- (1 / (2 * sqrt(pi))) * exp(- (xi / 2)^2)
         } else {
