@@ -184,17 +184,21 @@ DiscreteUniform <- R6Class("DiscreteUniform",
 
 
       return(1 / N * sum(z^(1:N))) # nolint
-    },
+    }
+  ),
 
-    # optional setParameterValue
-    #' @description
-    #' Sets the value(s) of the given parameter(s).
-    setParameterValue = function(..., lst = NULL, error = "warn", resolveConflicts = FALSE) {
-      super$setParameterValue(..., lst = lst, error = error, resolveConflicts = resolveConflicts)
-      private$.properties$support <-
-        Interval$new(self$getParameterValue("lower"), self$getParameterValue("upper"),
-                     class = "integer")
-      invisible(self)
+  active = list(
+    #' @field properties
+    #' Returns distribution properties, including skewness type and symmetry.
+    properties = function() {
+      prop <- super$properties
+      prop$support <- Interval$new(
+        self$getParameterValue("lower"),
+        self$getParameterValue("upper"),
+        class = "integer"
+      )
+
+      prop
     }
   ),
 
