@@ -184,16 +184,26 @@ MultivariateNormal <- R6Class("MultivariateNormal",
     # optional setParameterValue
     #' @description
     #' Sets the value(s) of the given parameter(s).
-    setParameterValue = function(..., lst = NULL, error = "warn", resolveConflicts = FALSE) {
-      if (is.null(lst)) lst <- list(...)
-      super$setParameterValue(lst = lst, error = error, resolveConflicts = resolveConflicts)
+    setParameterValue = function(..., lst = list(...), error = "warn", resolveConflicts = FALSE) {
+
+      super$setParameterValue(lst = lst)
       mean <- self$getParameterValue("mean")
       private$.variates <- length(mean)
-      private$.properties$support <- setpower(Reals$new(), length(mean))
       invisible(self)
     }
   ),
 
+  active = list(
+    #' @field properties
+    #' Returns distribution properties, including skewness type and symmetry.
+    properties = function() {
+      prop <- super$properties
+      prop$support <- setpower(Reals$new(),
+                               length(self$getParameterValue("mean")))
+      prop
+    }
+  ),
+
   private = list(
     # dpqr
     .pdf = function(x, log = FALSE) {
