@@ -1,5 +1,3 @@
-library(testthat)
-
 test_that("missing d/p/q", {
   expect_error(expect_message(
     plot(Distribution$new("s", pdf = function(x) x, type = Reals$new()), fun = "cdf"),
@@ -80,6 +78,7 @@ test_that("use_support", {
 })
 
 test_that("multivariate", {
+  skip_if_not_installed("plotly")
   dist <- MultivariateNormal$new()
   expect_silent(plot(dist, fun = "pdf", npoints = 10))
   expect_error(expect_message(plot(dist, fun = "cdf", npoints = 10)), "No plottable")
